<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Napsauta valikon kuvaketta 
tai lopeta tallennus painamalla pikakuvaketta uudelleen</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>Älä kierrä näyttöä tallennuksen aikana</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Kaappaus</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Tallennus</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Kaappaus</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Tallennus epäonnistui. Tallenna se kotihakemistoon.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Näytä</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Kaappaus valmiina</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>valitse alue</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Tallenna nimellä %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ohita</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Leikepöydälle</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Näyttöä tallennetaan, odota...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Koska ikkunatehosteet on poistettu käytöstä prosessin aikana, tallennus on pysäytetty</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Kaappaus</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Vierittävä kaappaus</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>Kiinnitä kaappaukset</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Avaa kansio</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>Kuvakeskuus on valmis ja kopioitu leikattavaksi</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Kumoa</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Poistu</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>Kiinnitä kaappaukset</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Kaappaus</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Tallenna</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Kaappaus</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Tallentaa</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Näytä</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Tallennus valmis</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Tallenna nimellä %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Avaa kansio</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Kaappaus alkaa %1 sekunnissa</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Hae apua.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>Jatkuvan kaappauksen ottaminen epäonnistui.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>Vieritysalueen alareuna saavutettu</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>Suurin pituus saavutettu</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>säädä kuvausaluetta</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Vieritä hiiren rullaa tai ota vierittävä kaappaus napsauttamalla</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Hidasta vieritysnopeutta</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>Virheellinen alue, napsauta </translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Kirjoita teksti tähän</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Aloita/Kaappaa</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Poistu/Tallenna</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Säädä koko</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Pikakäynnistys</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Ikkunan kaappaus</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Kaappaus viiveellä</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Kokoruudun kaappaus</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Poistu</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Suorakulmio</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Soikio</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Viiva</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Kynä</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Teksti</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Kumoa</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Lisää korkeutta ylöspäin</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Lisää mittaa alaspäin</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Lisää leveyttä vasemmalle</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Lisää leveyttä oikealle</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Pienennä korkeutta</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Pienennä mittaa alaosassa</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Pienennä leveyttä vasemmalla</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Pienennä leveyttä oikealla</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Apua</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Näytä kuvakkeet</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Ääni</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Näppäimistö</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Aloita tallennus</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Valinnat</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Aloita tallennus</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Hiiri</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Työkalut</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Poimi tekstiä</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Vierittävä kaappaus</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Kiinnitä kaappaukset</translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation>Aloita OCR</translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation>Aloita vierivä kaappaus</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Nuoli</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>Kaappaus</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation>Tallenna</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation>Suorakulmio
Piirrä neliö pitämällä Shift-painettuna</translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation>Ellipsi
Piirrä ympyrä pitämällä Shift-painettuna</translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation>Sivellin
Vedä suora viiva pitämällä Shift-painettuna</translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>Muuta läpikuultavuutta (vieritä säätääksesi)</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>Muuta siveltimen kokoa (vieritä säätääksesi)</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>Muuta tekstin kokoa (vieritä säätääksesi)</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation>Näytä näppäimistö (K)</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>Piilota näppäimistö (K)</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>Näytä näppäimistö (K)</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>Kytke kamera (C)</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>Sammuta kamera (C)</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Kaappaus</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>Asetukset (F3)</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Muoto:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Ääni</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofoni</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>Järjestelmän ääni</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Valinnat</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Näytä osoitin</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>Näytä painallus</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Tallenna nimellä</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Työpöytä</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videot</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>Viiva (L)
Vedä suora pysty- tai vaakaviiva pitämällä Shift-painettuna</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>Nuoli (X)
Vedä suora pysty- tai vaakanuoli pitämällä Shift-painettuna</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>Kynä (P)</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>Sumennus (B)</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>Teksti (T)</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>Vierivä kaappaus (Alt+I）</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>Poimi tekstiä (Alt+O）</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>Kiinnitä kaappaukset (Alt+P）</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>Kumoa (Ctrl+Z)</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Kuvat</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation>Aseta tallennuspolku</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Muuta polkua tallentaessa</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Muoto</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>Reunan tehosteet</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ei mitään</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>Varjo</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Reunus</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Laite</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Poimi tekstiä</translation>
    </message>
    <message>
        <source>Geometric Tools (R)
Hold down Shift to draw squares or circles.</source>
        <translation>Geometriset työkalut (R)
Pidä Shift-näppäintä painettuna piirtääksesi neliöitä tai ympyröitä.</translation>
    </message>
    <message>
        <source>Save to local</source>
        <translation>Tallenna paikallisesti</translation>
    </message>
    <message>
        <source>Save to Desktop</source>
        <translation>Tallenna työpöydälle</translation>
    </message>
    <message>
        <source>Save to Pictures</source>
        <translation>Tallenna kuvakkeisiin</translation>
    </message>
    <message>
        <source>Save to %1</source>
        <translation>Tallenna nimellä %1</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>Määritetty sijainti</translation>
    </message>
    <message>
        <source>Custom Location</source>
        <translation>Mukautettu sijainti</translation>
    </message>
    <message>
        <source>Each inquiry</source>
        <translation>Jokainen kysely</translation>
    </message>
    <message>
        <source>Update location on save</source>
        <translation>Päivitä sijainti tallessa</translation>
    </message>
    <message>
        <source>Save to desktop</source>
        <translation>Tallenna työpöydälle</translation>
    </message>
    <message>
        <source>Save to pictures</source>
        <translation>Tallenna kuvakkeisiin</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Sulje (Esc)</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>Kopioi leikepöydälle (Enter)</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> Säädä tallennuksen aluetta %1*%2 saadaksesi paremman videotehosteen</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>Näytön tallennusta ei tueta tällä hetkellä</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Poistu</translation>
    </message>
</context>
</TS>
